@@ -9,7 +9,7 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light;
 {
-    $Riak::Light::VERSION = '0.09911';
+    $Riak::Light::VERSION = '0.10';
 }
 ## use critic
 
@@ -31,18 +31,23 @@ use Moo;
 
 # ABSTRACT: Fast and lightweight Perl client for Riak
 
-has port    => ( is => 'ro', isa => Int,  required => 1 );
-has host    => ( is => 'ro', isa => Str,  required => 1 );
-has r       => ( is => 'ro', isa => Int,  default  => sub {2} );
-has w       => ( is => 'ro', isa => Int,  default  => sub {2} );
-has dw      => ( is => 'ro', isa => Int,  default  => sub {2} );
-has autodie => ( is => 'ro', isa => Bool, default  => sub {1}, trigger => 1 );
+has pid  => ( is => 'lazy', isa => Int, clearer  => 1 );
+has port => ( is => 'ro',   isa => Int, required => 1 );
+has host => ( is => 'ro',   isa => Str, required => 1 );
+has r    => ( is => 'ro',   isa => Int, default  => sub {2} );
+has w    => ( is => 'ro',   isa => Int, default  => sub {2} );
+has dw   => ( is => 'ro',   isa => Int, default  => sub {2} );
+has autodie => ( is => 'ro', isa => Bool, default => sub {1}, trigger => 1 );
 has timeout     => ( is => 'ro', isa => Num,  default => sub {0.5} );
 has tcp_nodelay => ( is => 'ro', isa => Bool, default => sub {1} );
 has in_timeout  => ( is => 'lazy', trigger => 1 );
 has out_timeout => ( is => 'lazy', trigger => 1 );
 has client_id   => ( is => 'lazy', isa     => Str );
 
+sub _build_pid {
+    $$;
+}
+
 sub _build_client_id {
     "perl_riak_light" . encode_base64( int( rand(10737411824) ), '' );
 }
@@ -76,7 +81,7 @@ has timeout_provider => (
     default => sub {'Riak::Light::Timeout::Select'}
 );
 
-has driver => ( is => 'lazy' );
+has driver => ( is => 'lazy', clearer => 1 );
 
 sub _build_driver {
     Riak::Light::Driver->new( socket => $_[0]->_build_socket() );
@@ -479,6 +484,10 @@ sub set_client_id {
     );
 }
 
+sub _pid_change {
+    $_[0]->pid != $$;
+}
+
 sub _parse_response {
     my ( $self, %args ) = @_;
 
@@ -497,6 +506,11 @@ sub _parse_response {
     $self->autodie
       or undef $@;    ## no critic (RequireLocalizedPunctuationVars)
 
+    if ( $self->_pid_change ) {
+        $self->clear_pid;
+        $self->clear_driver;
+    }
+
     $self->driver->perform_request(
         code => $request_code,
         body => $request_body
@@ -690,13 +704,15 @@ sub _process_generic_error {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Riak::Light - Fast and lightweight Perl client for Riak
 
 =head1 VERSION
 
-version 0.09911
+version 0.10
 
 =head1 SYNOPSIS
 
